# CS:GO Market API implementation
**CS:GO Markte API** - this module is a Python client library for CS:GO Market (CSGO.TM before) platform API (CS:GO Markte API wrapper)

**CS:GO Market** - one of the largest stores of virtual items from the CS:GO

**Market** - https://market.csgo.com/
**API Documentation** - https://market.csgo.com/docs-v2

# Installation
Install current version with [PyPi]():
```bash
pip install  *NAME*
```
Or from GitHub:
```bash
pip install https://github.com/wendland0d/csgotm-py/archive/refs/heads/main.zip
```